==> packageinstaller-pkglist-libre_0.1.3.tar.xz: packageinstaller-pkglist-libre/Italian_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
Italian_Thunderbird
</name>

<description>  
   <am>Italian localisation of Thunderbird</am>
   <ar>Italian localisation of Thunderbird</ar>
   <bg>Italian localisation of Thunderbird</bg>
   <bn>Italian localisation of Thunderbird</bn>
   <ca>Localització de Thunderbird en italià</ca>
   <cs>Italian localisation of Thunderbird</cs>
   <da>Italiensk oversættelse af Thunderbird</da>
   <de>Italienische Lokalisierung von Thunderbird</de>
   <el>Ιταλικός εντοπισμός του Thunderbird</el>
   <en>Italian localisation of Thunderbird</en>
   <es>Localización Italiana de Thunderbird</es>
   <et>Italian localisation of Thunderbird</et>
   <eu>Italian localisation of Thunderbird</eu>
   <fa>Italian localisation of Thunderbird</fa>
   <fil_PH>Italian localisation of Thunderbird</fil_PH>
   <fi>Italian localisation of Thunderbird</fi>
   <fr>Localisation italienne pour Thunderbird</fr>
   <he_IL>Italian localisation of Thunderbird</he_IL>
   <hi>Italian localisation of Thunderbird</hi>
   <hr>Italian localisation of Thunderbird</hr>
   <hu>Italian localisation of Thunderbird</hu>
   <id>Italian localisation of Thunderbird</id>
   <is>Italian localisation of Thunderbird</is>
   <it>Localizzazione italiana di Thunderbird</it>
   <ja_JP>Italian localisation of Thunderbird</ja_JP>
   <ja>Italian localisation of Thunderbird</ja>
   <kk>Italian localisation of Thunderbird</kk>
   <ko>Italian localisation of Thunderbird</ko>
   <lt>Italian localisation of Thunderbird</lt>
   <mk>Italian localisation of Thunderbird</mk>
   <mr>Italian localisation of Thunderbird</mr>
   <nb>Italian localisation of Thunderbird</nb>
   <nl>Italiaanse lokalisatie van Thunderbird</nl>
   <pl>Włoska lokalizacja Thunderbirda</pl>
   <pt_BR>Italiano Localização para Thunderbird</pt_BR>
   <pt>Italiano Localização para Thunderbird</pt>
   <ro>Italian localisation of Thunderbird</ro>
   <ru>Italian localisation of Thunderbird</ru>
   <sk>Italian localisation of Thunderbird</sk>
   <sl>Italian localisation of Thunderbird</sl>
   <sq>Italian localisation of Thunderbird</sq>
   <sr>Italian localisation of Thunderbird</sr>
   <sv>Italiensk lokalisering av Thunderbird</sv>
   <tr>Thunderbird'ün İtalyanca yerelleştirmesi</tr>
   <uk>Italian локалізація Thunderbird</uk>
   <vi>Italian localisation of Thunderbird</vi>
   <zh_CN>Italian localisation of Thunderbird</zh_CN>
   <zh_TW>Italian localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
thunderbird-l10n-it
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
thunderbird-l10n-it
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.10.tar.xz: packageinstaller-pkglist-libre/Italian_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Italian_Thunderbird
</name>

<description>
   <am>Italian localisation of Thunderbird</am>
   <ar>Italian localisation of Thunderbird</ar>
   <be>Italian localisation of Thunderbird</be>
   <bg>Italian localisation of Thunderbird</bg>
   <bn>Italian localisation of Thunderbird</bn>
   <ca>Localització de Thunderbird en italià</ca>
   <cs>Italian localisation of Thunderbird</cs>
   <da>Italiensk oversættelse af Thunderbird</da>
   <de>Italienische Lokalisierung von Thunderbird</de>
   <el>Ιταλικά για το Thunderbird</el>
   <en>Italian localisation of Thunderbird</en>
   <es_ES>Localización Italiana de Thunderbird</es_ES>
   <es>Localización Italiano de Thunderbird</es>
   <et>Italian localisation of Thunderbird</et>
   <eu>Italian localisation of Thunderbird</eu>
   <fa>Italian localisation of Thunderbird</fa>
   <fil_PH>Italian localisation of Thunderbird</fil_PH>
   <fi>Italialainen Thunderbird-kotoistus</fi>
   <fr_BE>Italian localisation of Thunderbird</fr_BE>
   <fr>Localisation en italien pour Thunderbird</fr>
   <gl_ES>Localización de Thunderbird ao italiano</gl_ES>
   <gu>Italian localisation of Thunderbird</gu>
   <he_IL>תרגומי Thunderbird לאיטלקית</he_IL>
   <hi>थंडरबर्ड का इतालवी संस्करण</hi>
   <hr>Italian localisation of Thunderbird</hr>
   <hu>Italian localisation of Thunderbird</hu>
   <id>Italian localisation of Thunderbird</id>
   <is>Italian localisation of Thunderbird</is>
   <it>Localizzazione italiana di Thunderbird</it>
   <ja>Thunderbird のイタリア語版</ja>
   <kk>Italian localisation of Thunderbird</kk>
   <ko>Italian localisation of Thunderbird</ko>
   <lt>Italian localisation of Thunderbird</lt>
   <mk>Italian localisation of Thunderbird</mk>
   <mr>Italian localisation of Thunderbird</mr>
   <nb_NO>Italian localisation of Thunderbird</nb_NO>
   <nb>Italiensk lokaltilpassing av Thunderbird</nb>
   <nl_BE>Italian localisation of Thunderbird</nl_BE>
   <nl>Italiaanse lokalisatie van Thunderbird</nl>
   <pl>Włoska lokalizacja Thunderbirda</pl>
   <pt_BR>Italiano Localização para o Thunderbird</pt_BR>
   <pt>Italiano Localização para Thunderbird</pt>
   <ro>Italian localisation of Thunderbird</ro>
   <ru>Italian localisation of Thunderbird</ru>
   <sk>Italian localisation of Thunderbird</sk>
   <sl>Italian localisation of Thunderbird</sl>
   <sq>Italian localisation of Thunderbird</sq>
   <sr>Italian localisation of Thunderbird</sr>
   <sv>Italiensk lokalisering av Thunderbird</sv>
   <th>Italian localisation ของ Thunderbird</th>
   <tr>Thunderbird'ün İtalyanca yerelleştirmesi</tr>
   <uk>Italian локалізація Thunderbird</uk>
   <vi>Italian localisation of Thunderbird</vi>
   <zh_CN>Italian localisation of Thunderbird</zh_CN>
   <zh_HK>Italian localisation of Thunderbird</zh_HK>
   <zh_TW>Italian localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
thunderbird-l10n-it
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
thunderbird-l10n-it
</uninstall_package_names>

</app>
